@@ -6,33 +6,30 @@ in many of my projects.
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-pyqt-controls"
-__date__ = "13-09-2022"
-__version__ = "1.2.0"
+__date__ = "20-03-2023"
+__version__ = "1.4.0"
 
-# Mechanism to support both PyQt and PySide
-# -----------------------------------------
 import os
 import sys
 
-QT_LIB = os.getenv("PYQTGRAPH_QT_LIB")
-PYSIDE = "PySide"
-PYSIDE2 = "PySide2"
-PYSIDE6 = "PySide6"
-PYQT4 = "PyQt4"
+# Mechanism to support both PyQt and PySide
+# -----------------------------------------
+
 PYQT5 = "PyQt5"
 PYQT6 = "PyQt6"
+PYSIDE2 = "PySide2"
+PYSIDE6 = "PySide6"
+QT_LIB_ORDER = [PYQT5, PYSIDE2, PYSIDE6, PYQT6]
+QT_LIB = None
 
-# pylint: disable=import-error, no-name-in-module
-# fmt: off
 if QT_LIB is None:
-    libOrder = [PYQT5, PYSIDE2, PYSIDE6, PYQT6]
-    for lib in libOrder:
+    for lib in QT_LIB_ORDER:
         if lib in sys.modules:
             QT_LIB = lib
             break
 
 if QT_LIB is None:
-    for lib in libOrder:
+    for lib in QT_LIB_ORDER:
         try:
             __import__(lib)
             QT_LIB = lib
@@ -41,11 +38,14 @@ if QT_LIB is None:
             pass
 
 if QT_LIB is None:
-    raise Exception(
-        "DvG_PyQt_controls requires PyQt5, PyQt6, PySide2 or PySide6; "
+    this_file = __file__.split(os.sep)[-1]
+    raise ImportError(
+        f"{this_file} requires PyQt5, PyQt6, PySide2 or PySide6; "
         "none of these packages could be imported."
     )
 
+# fmt: off
+# pylint: disable=import-error, no-name-in-module
 if QT_LIB == PYQT5:
     from PyQt5 import QtCore, QtGui, QtWidgets as QtWid    # type: ignore
 elif QT_LIB == PYQT6:
@@ -54,9 +54,9 @@ elif QT_LIB == PYSIDE2:
     from PySide2 import QtCore, QtGui, QtWidgets as QtWid  # type: ignore
 elif QT_LIB == PYSIDE6:
     from PySide6 import QtCore, QtGui, QtWidgets as QtWid  # type: ignore
-
-# fmt: on
 # pylint: enable=import-error, no-name-in-module
+# fmt: on
+
 # \end[Mechanism to support both PyQt and PySide]
 # -----------------------------------------------
 
@@ -202,7 +202,7 @@ SS_GROUP = (
         "border-radius: 5px;"
         "font: bold;"
         "padding: 8 0 0 0px;"
-        "margin-top: 2ex;}"
+        "margin-top: " + ("2ex" if QT_LIB in (PYQT5, PYSIDE2) else "1.2ex") + ";}"
     "QGroupBox:title {"
         "subcontrol-origin: margin;"
         "subcontrol-position: top left;"
@@ -220,7 +220,7 @@ SS_GROUP_RECT = (
         "border-radius: 0px;"
         "font: bold;"
         "margin: 0;"
-        "padding: 14 0 0 0px;}"
+        "padding: 3ex 0 0 0;}"
     "QGroupBox::title {"
         "subcontrol-origin: margin;"
         "subcontrol-position: top left;"
@@ -311,6 +311,21 @@ SS_TINY_ERROR_LED = (
 # fmt: on
 
 
+def e8(
+    N: int,
+    font: QtGui.QFont = None,
+    extra_padding: int = 14,
+) -> int:
+    """Return the pixel width that is necessary to fit `N` number of '8's in the
+    supplied `font`. In analogy to the 'em' font-metric, but now focused on
+    displaying numeric values.
+    """
+    if font is None:
+        font = QtGui.QGuiApplication.font()
+    qfm = QtGui.QFontMetrics(font)
+    return qfm.horizontalAdvance("8") * N + extra_padding
+
+
 def create_LED_indicator(**kwargs) -> QtWid.QPushButton:
     """Useful kwargs:
       text: str, icon: QIcon, checked: bool, parent
